ananke.estimation package
=========================

Submodules
----------

ananke.estimation.automated\_if module
--------------------------------------

.. automodule:: ananke.estimation.automated_if
   :members:
   :undoc-members:
   :show-inheritance:

ananke.estimation.counterfactual\_mean module
---------------------------------------------

.. automodule:: ananke.estimation.counterfactual_mean
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: ananke.estimation
   :members:
   :undoc-members:
   :show-inheritance:
